==> jc-1.4.0.tar.gz: polyglot/util/BitVector.h <==
// public class polyglot.util.BitVector

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bf938afdd55b4b57 polyglot_util_BitVector

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_BitVector_H_
#define _JC_polyglot_util_BitVector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_BitVector$sub_refs	_jc_polyglot_util_BitVector$sub_refs;
typedef struct _jc_polyglot_util_BitVector$sub_nonrefs	_jc_polyglot_util_BitVector$sub_nonrefs;
typedef struct _jc_polyglot_util_BitVector$refs	_jc_polyglot_util_BitVector$refs;
typedef struct _jc_polyglot_util_BitVector$nonrefs	_jc_polyglot_util_BitVector$nonrefs;
typedef struct _jc_polyglot_util_BitVector$object	_jc_polyglot_util_BitVector$object;

typedef const struct _jc_polyglot_util_BitVector$vmethods	_jc_polyglot_util_BitVector$vmethods;
typedef const struct _jc_polyglot_util_BitVector$vtable	_jc_polyglot_util_BitVector$vtable;
typedef const struct _jc_polyglot_util_BitVector$vtype	_jc_polyglot_util_BitVector$vtype;

// Constructors
extern void _jc_polyglot_util_BitVector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_BitVector$object *);
extern void _jc_polyglot_util_BitVector$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint);

// Virtual methods
extern jboolean _jc_polyglot_util_BitVector$method$getBit$133932e7735798cc(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint);
extern void _jc_polyglot_util_BitVector$method$setBit$7786d1c6cbd6b37c(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint, jboolean);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_BitVector$method_info$getBit$133932e7735798cc;
extern _jc_method _jc_polyglot_util_BitVector$method_info$setBit$7786d1c6cbd6b37c;

// Virtual methods structure
struct _jc_polyglot_util_BitVector$vmethods {
	jboolean	(*getBit$133932e7735798cc)(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint);
	void	(*setBit$7786d1c6cbd6b37c)(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint, jboolean);
};

// Vtable
struct _jc_polyglot_util_BitVector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_BitVector$vmethods	polyglot_util_BitVector;
};

// Vtype
struct _jc_polyglot_util_BitVector$vtype {
	_jc_type			type;
	_jc_polyglot_util_BitVector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_BitVector$sub_refs {
	_jc_boolean_array	*bits;
};

// Reference instance fields (object)
struct _jc_polyglot_util_BitVector$refs {
    _jc_polyglot_util_BitVector$sub_refs	polyglot_util_BitVector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_BitVector$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_BitVector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_BitVector$sub_nonrefs	polyglot_util_BitVector;
};

// Object instance structure
struct _jc_polyglot_util_BitVector$object {
	_jc_polyglot_util_BitVector$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_BitVector$vtype	*vtype;
	_jc_polyglot_util_BitVector$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_BitVector$vtype _jc_polyglot_util_BitVector$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_BitVector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_BitVector$class_object;

#endif	/* _JC_polyglot_util_BitVector_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/BitVector.h <==
// public class polyglot.util.BitVector

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bf938afdd55b4b57 polyglot_util_BitVector

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_BitVector_H_
#define _JC_polyglot_util_BitVector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_util_BitVector$sub_refs	_jc_polyglot_util_BitVector$sub_refs;
typedef struct _jc_polyglot_util_BitVector$sub_nonrefs	_jc_polyglot_util_BitVector$sub_nonrefs;
typedef struct _jc_polyglot_util_BitVector$refs	_jc_polyglot_util_BitVector$refs;
typedef struct _jc_polyglot_util_BitVector$nonrefs	_jc_polyglot_util_BitVector$nonrefs;
typedef struct _jc_polyglot_util_BitVector$object	_jc_polyglot_util_BitVector$object;

typedef const struct _jc_polyglot_util_BitVector$vmethods	_jc_polyglot_util_BitVector$vmethods;
typedef const struct _jc_polyglot_util_BitVector$vtable	_jc_polyglot_util_BitVector$vtable;
typedef const struct _jc_polyglot_util_BitVector$vtype	_jc_polyglot_util_BitVector$vtype;

// Constructors
extern void _jc_polyglot_util_BitVector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_BitVector$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_BitVector$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_BitVector$method$getBit$133932e7735798cc(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_BitVector$method$setBit$7786d1c6cbd6b37c(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_BitVector$method_info$getBit$133932e7735798cc;
extern _jc_method _jc_polyglot_util_BitVector$method_info$setBit$7786d1c6cbd6b37c;

// Virtual methods structure
struct _jc_polyglot_util_BitVector$vmethods {
	jboolean	(*getBit$133932e7735798cc)(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint) _JC_JCNI_ATTR;
	void	(*setBit$7786d1c6cbd6b37c)(_jc_env *, struct _jc_polyglot_util_BitVector$object *, jint, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_BitVector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_BitVector$vmethods	polyglot_util_BitVector;
};

// Vtype
struct _jc_polyglot_util_BitVector$vtype {
	_jc_type			type;
	_jc_polyglot_util_BitVector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_BitVector$sub_refs {
	_jc_boolean_array	*bits;
};

// Reference instance fields (object)
struct _jc_polyglot_util_BitVector$refs {
    _jc_polyglot_util_BitVector$sub_refs	polyglot_util_BitVector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_BitVector$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_BitVector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_BitVector$sub_nonrefs	polyglot_util_BitVector;
};

// Object instance structure
struct _jc_polyglot_util_BitVector$object {
	_jc_polyglot_util_BitVector$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_BitVector$vtype	*vtype;
	_jc_polyglot_util_BitVector$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_BitVector$vtype _jc_polyglot_util_BitVector$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_BitVector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_BitVector$class_object;

#endif	/* _JC_polyglot_util_BitVector_H_ */
